Introduction
============

.. todo: find / write a good introduction for fpga design in general

If you are not familiar with nMigen specifically or FPGA design in general, 
I recommend to start reading the `nMigen documentation <https://nmigen.info/nmigen/latest/intro.html>`__. 

Generally I think that image processing is a great way to get started with FPGA
design and nMigen is especially a good start. Probably you will experience 
many rough edges and some frustration but also for me mMigen and this project were
the first big project with reconfigurable hardware :).
